# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Iterable

import httpx

from ..types import upsert_simulation_create_params
from .._types import NOT_GIVEN, Body, Query, Headers, NotGiven
from .._utils import maybe_transform, async_maybe_transform
from .._compat import cached_property
from .._resource import SyncAPIResource, AsyncAPIResource
from .._response import (
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    async_to_streamed_response_wrapper,
)
from .._base_client import make_request_options
from ..types.upsert_simulation_create_response import UpsertSimulationCreateResponse

__all__ = ["UpsertSimulationResource", "AsyncUpsertSimulationResource"]


class UpsertSimulationResource(SyncAPIResource):
    @cached_property
    def with_raw_response(self) -> UpsertSimulationResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/Fluidize-Inc/fluidize-python-sdk#accessing-raw-response-data-eg-headers
        """
        return UpsertSimulationResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> UpsertSimulationResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/Fluidize-Inc/fluidize-python-sdk#with_streaming_response
        """
        return UpsertSimulationResourceWithStreamingResponse(self)

    def create(
        self,
        *,
        container_image: str,
        environment_variables: Iterable[upsert_simulation_create_params.EnvironmentVariable],
        name: str,
        package_managers: Iterable[upsert_simulation_create_params.PackageManager],
        post_install_script: str,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> UpsertSimulationCreateResponse:
        """
        Upsert Simulation

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return self._post(
            "/upsert_simulation",
            body=maybe_transform(
                {
                    "container_image": container_image,
                    "environment_variables": environment_variables,
                    "name": name,
                    "package_managers": package_managers,
                    "post_install_script": post_install_script,
                },
                upsert_simulation_create_params.UpsertSimulationCreateParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=UpsertSimulationCreateResponse,
        )


class AsyncUpsertSimulationResource(AsyncAPIResource):
    @cached_property
    def with_raw_response(self) -> AsyncUpsertSimulationResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/Fluidize-Inc/fluidize-python-sdk#accessing-raw-response-data-eg-headers
        """
        return AsyncUpsertSimulationResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncUpsertSimulationResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/Fluidize-Inc/fluidize-python-sdk#with_streaming_response
        """
        return AsyncUpsertSimulationResourceWithStreamingResponse(self)

    async def create(
        self,
        *,
        container_image: str,
        environment_variables: Iterable[upsert_simulation_create_params.EnvironmentVariable],
        name: str,
        package_managers: Iterable[upsert_simulation_create_params.PackageManager],
        post_install_script: str,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> UpsertSimulationCreateResponse:
        """
        Upsert Simulation

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return await self._post(
            "/upsert_simulation",
            body=await async_maybe_transform(
                {
                    "container_image": container_image,
                    "environment_variables": environment_variables,
                    "name": name,
                    "package_managers": package_managers,
                    "post_install_script": post_install_script,
                },
                upsert_simulation_create_params.UpsertSimulationCreateParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=UpsertSimulationCreateResponse,
        )


class UpsertSimulationResourceWithRawResponse:
    def __init__(self, upsert_simulation: UpsertSimulationResource) -> None:
        self._upsert_simulation = upsert_simulation

        self.create = to_raw_response_wrapper(
            upsert_simulation.create,
        )


class AsyncUpsertSimulationResourceWithRawResponse:
    def __init__(self, upsert_simulation: AsyncUpsertSimulationResource) -> None:
        self._upsert_simulation = upsert_simulation

        self.create = async_to_raw_response_wrapper(
            upsert_simulation.create,
        )


class UpsertSimulationResourceWithStreamingResponse:
    def __init__(self, upsert_simulation: UpsertSimulationResource) -> None:
        self._upsert_simulation = upsert_simulation

        self.create = to_streamed_response_wrapper(
            upsert_simulation.create,
        )


class AsyncUpsertSimulationResourceWithStreamingResponse:
    def __init__(self, upsert_simulation: AsyncUpsertSimulationResource) -> None:
        self._upsert_simulation = upsert_simulation

        self.create = async_to_streamed_response_wrapper(
            upsert_simulation.create,
        )



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import List, Optional
from typing_extensions import Required, TypedDict

from .project_summary_param import ProjectSummaryParam

__all__ = ["RunRunFlowParams", "Payload"]


class RunRunFlowParams(TypedDict, total=False):
    payload: Required[Payload]

    project: Required[ProjectSummaryParam]


class Payload(TypedDict, total=False):
    description: Optional[str]

    name: Optional[str]

    tags: Optional[List[str]]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from .ssh_connect_params import SSHConnectParams as SSHConnectParams
from .ssh_connect_response import SSHConnectResponse as SSHConnectResponse



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import httpx

from ..types import simulation_list_simulations_params
from .._types import NOT_GIVEN, Body, Query, Headers, NotGiven
from .._utils import maybe_transform, async_maybe_transform
from .._compat import cached_property
from .._resource import SyncAPIResource, AsyncAPIResource
from .._response import (
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    async_to_streamed_response_wrapper,
)
from .._base_client import make_request_options
from ..types.simulation_list_simulations_response import SimulationListSimulationsResponse

__all__ = ["SimulationResource", "AsyncSimulationResource"]


class SimulationResource(SyncAPIResource):
    @cached_property
    def with_raw_response(self) -> SimulationResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/Fluidize-Inc/fluidize-python-sdk#accessing-raw-response-data-eg-headers
        """
        return SimulationResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> SimulationResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/Fluidize-Inc/fluidize-python-sdk#with_streaming_response
        """
        return SimulationResourceWithStreamingResponse(self)

    def list_simulations(
        self,
        *,
        sim_global: bool,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> SimulationListSimulationsResponse:
        """Get a list of all simulation nodes available in the system.

        This function does
        not need to change as it reads from a different source.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return self._get(
            "/simulation/list_simulations",
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=maybe_transform(
                    {"sim_global": sim_global}, simulation_list_simulations_params.SimulationListSimulationsParams
                ),
            ),
            cast_to=SimulationListSimulationsResponse,
        )


class AsyncSimulationResource(AsyncAPIResource):
    @cached_property
    def with_raw_response(self) -> AsyncSimulationResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/Fluidize-Inc/fluidize-python-sdk#accessing-raw-response-data-eg-headers
        """
        return AsyncSimulationResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncSimulationResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/Fluidize-Inc/fluidize-python-sdk#with_streaming_response
        """
        return AsyncSimulationResourceWithStreamingResponse(self)

    async def list_simulations(
        self,
        *,
        sim_global: bool,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> SimulationListSimulationsResponse:
        """Get a list of all simulation nodes available in the system.

        This function does
        not need to change as it reads from a different source.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return await self._get(
            "/simulation/list_simulations",
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=await async_maybe_transform(
                    {"sim_global": sim_global}, simulation_list_simulations_params.SimulationListSimulationsParams
                ),
            ),
            cast_to=SimulationListSimulationsResponse,
        )


class SimulationResourceWithRawResponse:
    def __init__(self, simulation: SimulationResource) -> None:
        self._simulation = simulation

        self.list_simulations = to_raw_response_wrapper(
            simulation.list_simulations,
        )


class AsyncSimulationResourceWithRawResponse:
    def __init__(self, simulation: AsyncSimulationResource) -> None:
        self._simulation = simulation

        self.list_simulations = async_to_raw_response_wrapper(
            simulation.list_simulations,
        )


class SimulationResourceWithStreamingResponse:
    def __init__(self, simulation: SimulationResource) -> None:
        self._simulation = simulation

        self.list_simulations = to_streamed_response_wrapper(
            simulation.list_simulations,
        )


class AsyncSimulationResourceWithStreamingResponse:
    def __init__(self, simulation: AsyncSimulationResource) -> None:
        self._simulation = simulation

        self.list_simulations = async_to_streamed_response_wrapper(
            simulation.list_simulations,
        )



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import Required, TypedDict

__all__ = ["SSHConnectParams"]


class SSHConnectParams(TypedDict, total=False):
    password: Required[str]

    username: Required[str]

    verification_code: Required[str]

    host: str

    port: int



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from ..._compat import cached_property
from ..._resource import SyncAPIResource, AsyncAPIResource
from .retrieval_mode import (
    RetrievalModeResource,
    AsyncRetrievalModeResource,
    RetrievalModeResourceWithRawResponse,
    AsyncRetrievalModeResourceWithRawResponse,
    RetrievalModeResourceWithStreamingResponse,
    AsyncRetrievalModeResourceWithStreamingResponse,
)

__all__ = ["UtilsResource", "AsyncUtilsResource"]


class UtilsResource(SyncAPIResource):
    @cached_property
    def retrieval_mode(self) -> RetrievalModeResource:
        return RetrievalModeResource(self._client)

    @cached_property
    def with_raw_response(self) -> UtilsResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/Fluidize-Inc/fluidize-python-sdk#accessing-raw-response-data-eg-headers
        """
        return UtilsResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> UtilsResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/Fluidize-Inc/fluidize-python-sdk#with_streaming_response
        """
        return UtilsResourceWithStreamingResponse(self)


class AsyncUtilsResource(AsyncAPIResource):
    @cached_property
    def retrieval_mode(self) -> AsyncRetrievalModeResource:
        return AsyncRetrievalModeResource(self._client)

    @cached_property
    def with_raw_response(self) -> AsyncUtilsResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/Fluidize-Inc/fluidize-python-sdk#accessing-raw-response-data-eg-headers
        """
        return AsyncUtilsResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncUtilsResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/Fluidize-Inc/fluidize-python-sdk#with_streaming_response
        """
        return AsyncUtilsResourceWithStreamingResponse(self)


class UtilsResourceWithRawResponse:
    def __init__(self, utils: UtilsResource) -> None:
        self._utils = utils

    @cached_property
    def retrieval_mode(self) -> RetrievalModeResourceWithRawResponse:
        return RetrievalModeResourceWithRawResponse(self._utils.retrieval_mode)


class AsyncUtilsResourceWithRawResponse:
    def __init__(self, utils: AsyncUtilsResource) -> None:
        self._utils = utils

    @cached_property
    def retrieval_mode(self) -> AsyncRetrievalModeResourceWithRawResponse:
        return AsyncRetrievalModeResourceWithRawResponse(self._utils.retrieval_mode)


class UtilsResourceWithStreamingResponse:
    def __init__(self, utils: UtilsResource) -> None:
        self._utils = utils

    @cached_property
    def retrieval_mode(self) -> RetrievalModeResourceWithStreamingResponse:
        return RetrievalModeResourceWithStreamingResponse(self._utils.retrieval_mode)


class AsyncUtilsResourceWithStreamingResponse:
    def __init__(self, utils: AsyncUtilsResource) -> None:
        self._utils = utils

    @cached_property
    def retrieval_mode(self) -> AsyncRetrievalModeResourceWithStreamingResponse:
        return AsyncRetrievalModeResourceWithStreamingResponse(self._utils.retrieval_mode)



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import os
from typing import Any, Union, Mapping
from typing_extensions import Self, override

import httpx

from . import _exceptions
from ._qs import Querystring
from ._types import (
    NOT_GIVEN,
    Body,
    Omit,
    Query,
    Headers,
    Timeout,
    NotGiven,
    Transport,
    ProxiesTypes,
    RequestOptions,
)
from ._utils import is_given, get_async_library
from ._version import __version__
from ._response import (
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    async_to_streamed_response_wrapper,
)
from .resources import candy, files, graph, projects, simulation, test_connection, list_environments, upsert_simulation
from ._streaming import Stream as Stream, AsyncStream as AsyncStream
from ._exceptions import APIStatusError, FluidizeSDKError
from ._base_client import (
    DEFAULT_MAX_RETRIES,
    SyncAPIClient,
    AsyncAPIClient,
    make_request_options,
)
from .resources.auth import auth
from .resources.runs import runs
from .resources.utils import utils

__all__ = [
    "Timeout",
    "Transport",
    "ProxiesTypes",
    "RequestOptions",
    "FluidizeSDK",
    "AsyncFluidizeSDK",
    "Client",
    "AsyncClient",
]


class FluidizeSDK(SyncAPIClient):
    test_connection: test_connection.TestConnectionResource
    candy: candy.CandyResource
    graph: graph.GraphResource
    projects: projects.ProjectsResource
    files: files.FilesResource
    runs: runs.RunsResource
    auth: auth.AuthResource
    list_environments: list_environments.ListEnvironmentsResource
    upsert_simulation: upsert_simulation.UpsertSimulationResource
    utils: utils.UtilsResource
    simulation: simulation.SimulationResource
    with_raw_response: FluidizeSDKWithRawResponse
    with_streaming_response: FluidizeSDKWithStreamedResponse

    # client options
    api_token: str

    def __init__(
        self,
        *,
        api_token: str | None = None,
        base_url: str | httpx.URL | None = None,
        timeout: Union[float, Timeout, None, NotGiven] = NOT_GIVEN,
        max_retries: int = DEFAULT_MAX_RETRIES,
        default_headers: Mapping[str, str] | None = None,
        default_query: Mapping[str, object] | None = None,
        # Configure a custom httpx client.
        # We provide a `DefaultHttpxClient` class that you can pass to retain the default values we use for `limits`, `timeout` & `follow_redirects`.
        # See the [httpx documentation](https://www.python-httpx.org/api/#client) for more details.
        http_client: httpx.Client | None = None,
        # Enable or disable schema validation for data returned by the API.
        # When enabled an error APIResponseValidationError is raised
        # if the API responds with invalid data for the expected schema.
        #
        # This parameter may be removed or changed in the future.
        # If you rely on this feature, please open a GitHub issue
        # outlining your use-case to help us decide if it should be
        # part of our public interface in the future.
        _strict_response_validation: bool = False,
    ) -> None:
        """Construct a new synchronous FluidizeSDK client instance.

        This automatically infers the `api_token` argument from the `FLUIDIZE_API_TOKEN` environment variable if it is not provided.
        """
        if api_token is None:
            api_token = os.environ.get("FLUIDIZE_API_TOKEN")
        if api_token is None:
            raise FluidizeSDKError(
                "The api_token client option must be set either by passing api_token to the client or by setting the FLUIDIZE_API_TOKEN environment variable"
            )
        self.api_token = api_token

        if base_url is None:
            base_url = os.environ.get("FLUIDIZE_SDK_BASE_URL")
        if base_url is None:
            base_url = f"https://api.fluidize.ai"

        super().__init__(
            version=__version__,
            base_url=base_url,
            max_retries=max_retries,
            timeout=timeout,
            http_client=http_client,
            custom_headers=default_headers,
            custom_query=default_query,
            _strict_response_validation=_strict_response_validation,
        )

        self.test_connection = test_connection.TestConnectionResource(self)
        self.candy = candy.CandyResource(self)
        self.graph = graph.GraphResource(self)
        self.projects = projects.ProjectsResource(self)
        self.files = files.FilesResource(self)
        self.runs = runs.RunsResource(self)
        self.auth = auth.AuthResource(self)
        self.list_environments = list_environments.ListEnvironmentsResource(self)
        self.upsert_simulation = upsert_simulation.UpsertSimulationResource(self)
        self.utils = utils.UtilsResource(self)
        self.simulation = simulation.SimulationResource(self)
        self.with_raw_response = FluidizeSDKWithRawResponse(self)
        self.with_streaming_response = FluidizeSDKWithStreamedResponse(self)

    @property
    @override
    def qs(self) -> Querystring:
        return Querystring(array_format="comma")

    @property
    @override
    def auth_headers(self) -> dict[str, str]:
        api_token = self.api_token
        return {"Authorization": f"Bearer {api_token}"}

    @property
    @override
    def default_headers(self) -> dict[str, str | Omit]:
        return {
            **super().default_headers,
            "X-Stainless-Async": "false",
            **self._custom_headers,
        }

    def copy(
        self,
        *,
        api_token: str | None = None,
        base_url: str | httpx.URL | None = None,
        timeout: float | Timeout | None | NotGiven = NOT_GIVEN,
        http_client: httpx.Client | None = None,
        max_retries: int | NotGiven = NOT_GIVEN,
        default_headers: Mapping[str, str] | None = None,
        set_default_headers: Mapping[str, str] | None = None,
        default_query: Mapping[str, object] | None = None,
        set_default_query: Mapping[str, object] | None = None,
        _extra_kwargs: Mapping[str, Any] = {},
    ) -> Self:
        """
        Create a new client instance re-using the same options given to the current client with optional overriding.
        """
        if default_headers is not None and set_default_headers is not None:
            raise ValueError("The `default_headers` and `set_default_headers` arguments are mutually exclusive")

        if default_query is not None and set_default_query is not None:
            raise ValueError("The `default_query` and `set_default_query` arguments are mutually exclusive")

        headers = self._custom_headers
        if default_headers is not None:
            headers = {**headers, **default_headers}
        elif set_default_headers is not None:
            headers = set_default_headers

        params = self._custom_query
        if default_query is not None:
            params = {**params, **default_query}
        elif set_default_query is not None:
            params = set_default_query

        http_client = http_client or self._client
        return self.__class__(
            api_token=api_token or self.api_token,
            base_url=base_url or self.base_url,
            timeout=self.timeout if isinstance(timeout, NotGiven) else timeout,
            http_client=http_client,
            max_retries=max_retries if is_given(max_retries) else self.max_retries,
            default_headers=headers,
            default_query=params,
            **_extra_kwargs,
        )

    # Alias for `copy` for nicer inline usage, e.g.
    # client.with_options(timeout=10).foo.create(...)
    with_options = copy

    def retrieve_root(
        self,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> object:
        """Read Root"""
        return self.get(
            "/",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=object,
        )

    @override
    def _make_status_error(
        self,
        err_msg: str,
        *,
        body: object,
        response: httpx.Response,
    ) -> APIStatusError:
        if response.status_code == 400:
            return _exceptions.BadRequestError(err_msg, response=response, body=body)

        if response.status_code == 401:
            return _exceptions.AuthenticationError(err_msg, response=response, body=body)

        if response.status_code == 403:
            return _exceptions.PermissionDeniedError(err_msg, response=response, body=body)

        if response.status_code == 404:
            return _exceptions.NotFoundError(err_msg, response=response, body=body)

        if response.status_code == 409:
            return _exceptions.ConflictError(err_msg, response=response, body=body)

        if response.status_code == 422:
            return _exceptions.UnprocessableEntityError(err_msg, response=response, body=body)

        if response.status_code == 429:
            return _exceptions.RateLimitError(err_msg, response=response, body=body)

        if response.status_code >= 500:
            return _exceptions.InternalServerError(err_msg, response=response, body=body)
        return APIStatusError(err_msg, response=response, body=body)


class AsyncFluidizeSDK(AsyncAPIClient):
    test_connection: test_connection.AsyncTestConnectionResource
    candy: candy.AsyncCandyResource
    graph: graph.AsyncGraphResource
    projects: projects.AsyncProjectsResource
    files: files.AsyncFilesResource
    runs: runs.AsyncRunsResource
    auth: auth.AsyncAuthResource
    list_environments: list_environments.AsyncListEnvironmentsResource
    upsert_simulation: upsert_simulation.AsyncUpsertSimulationResource
    utils: utils.AsyncUtilsResource
    simulation: simulation.AsyncSimulationResource
    with_raw_response: AsyncFluidizeSDKWithRawResponse
    with_streaming_response: AsyncFluidizeSDKWithStreamedResponse

    # client options
    api_token: str

    def __init__(
        self,
        *,
        api_token: str | None = None,
        base_url: str | httpx.URL | None = None,
        timeout: Union[float, Timeout, None, NotGiven] = NOT_GIVEN,
        max_retries: int = DEFAULT_MAX_RETRIES,
        default_headers: Mapping[str, str] | None = None,
        default_query: Mapping[str, object] | None = None,
        # Configure a custom httpx client.
        # We provide a `DefaultAsyncHttpxClient` class that you can pass to retain the default values we use for `limits`, `timeout` & `follow_redirects`.
        # See the [httpx documentation](https://www.python-httpx.org/api/#asyncclient) for more details.
        http_client: httpx.AsyncClient | None = None,
        # Enable or disable schema validation for data returned by the API.
        # When enabled an error APIResponseValidationError is raised
        # if the API responds with invalid data for the expected schema.
        #
        # This parameter may be removed or changed in the future.
        # If you rely on this feature, please open a GitHub issue
        # outlining your use-case to help us decide if it should be
        # part of our public interface in the future.
        _strict_response_validation: bool = False,
    ) -> None:
        """Construct a new async AsyncFluidizeSDK client instance.

        This automatically infers the `api_token` argument from the `FLUIDIZE_API_TOKEN` environment variable if it is not provided.
        """
        if api_token is None:
            api_token = os.environ.get("FLUIDIZE_API_TOKEN")
        if api_token is None:
            raise FluidizeSDKError(
                "The api_token client option must be set either by passing api_token to the client or by setting the FLUIDIZE_API_TOKEN environment variable"
            )
        self.api_token = api_token

        if base_url is None:
            base_url = os.environ.get("FLUIDIZE_SDK_BASE_URL")
        if base_url is None:
            base_url = f"https://api.fluidize.ai"

        super().__init__(
            version=__version__,
            base_url=base_url,
            max_retries=max_retries,
            timeout=timeout,
            http_client=http_client,
            custom_headers=default_headers,
            custom_query=default_query,
            _strict_response_validation=_strict_response_validation,
        )

        self.test_connection = test_connection.AsyncTestConnectionResource(self)
        self.candy = candy.AsyncCandyResource(self)
        self.graph = graph.AsyncGraphResource(self)
        self.projects = projects.AsyncProjectsResource(self)
        self.files = files.AsyncFilesResource(self)
        self.runs = runs.AsyncRunsResource(self)
        self.auth = auth.AsyncAuthResource(self)
        self.list_environments = list_environments.AsyncListEnvironmentsResource(self)
        self.upsert_simulation = upsert_simulation.AsyncUpsertSimulationResource(self)
        self.utils = utils.AsyncUtilsResource(self)
        self.simulation = simulation.AsyncSimulationResource(self)
        self.with_raw_response = AsyncFluidizeSDKWithRawResponse(self)
        self.with_streaming_response = AsyncFluidizeSDKWithStreamedResponse(self)

    @property
    @override
    def qs(self) -> Querystring:
        return Querystring(array_format="comma")

    @property
    @override
    def auth_headers(self) -> dict[str, str]:
        api_token = self.api_token
        return {"Authorization": f"Bearer {api_token}"}

    @property
    @override
    def default_headers(self) -> dict[str, str | Omit]:
        return {
            **super().default_headers,
            "X-Stainless-Async": f"async:{get_async_library()}",
            **self._custom_headers,
        }

    def copy(
        self,
        *,
        api_token: str | None = None,
        base_url: str | httpx.URL | None = None,
        timeout: float | Timeout | None | NotGiven = NOT_GIVEN,
        http_client: httpx.AsyncClient | None = None,
        max_retries: int | NotGiven = NOT_GIVEN,
        default_headers: Mapping[str, str] | None = None,
        set_default_headers: Mapping[str, str] | None = None,
        default_query: Mapping[str, object] | None = None,
        set_default_query: Mapping[str, object] | None = None,
        _extra_kwargs: Mapping[str, Any] = {},
    ) -> Self:
        """
        Create a new client instance re-using the same options given to the current client with optional overriding.
        """
        if default_headers is not None and set_default_headers is not None:
            raise ValueError("The `default_headers` and `set_default_headers` arguments are mutually exclusive")

        if default_query is not None and set_default_query is not None:
            raise ValueError("The `default_query` and `set_default_query` arguments are mutually exclusive")

        headers = self._custom_headers
        if default_headers is not None:
            headers = {**headers, **default_headers}
        elif set_default_headers is not None:
            headers = set_default_headers

        params = self._custom_query
        if default_query is not None:
            params = {**params, **default_query}
        elif set_default_query is not None:
            params = set_default_query

        http_client = http_client or self._client
        return self.__class__(
            api_token=api_token or self.api_token,
            base_url=base_url or self.base_url,
            timeout=self.timeout if isinstance(timeout, NotGiven) else timeout,
            http_client=http_client,
            max_retries=max_retries if is_given(max_retries) else self.max_retries,
            default_headers=headers,
            default_query=params,
            **_extra_kwargs,
        )

    # Alias for `copy` for nicer inline usage, e.g.
    # client.with_options(timeout=10).foo.create(...)
    with_options = copy

    async def retrieve_root(
        self,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> object:
        """Read Root"""
        return await self.get(
            "/",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=object,
        )

    @override
    def _make_status_error(
        self,
        err_msg: str,
        *,
        body: object,
        response: httpx.Response,
    ) -> APIStatusError:
        if response.status_code == 400:
            return _exceptions.BadRequestError(err_msg, response=response, body=body)

        if response.status_code == 401:
            return _exceptions.AuthenticationError(err_msg, response=response, body=body)

        if response.status_code == 403:
            return _exceptions.PermissionDeniedError(err_msg, response=response, body=body)

        if response.status_code == 404:
            return _exceptions.NotFoundError(err_msg, response=response, body=body)

        if response.status_code == 409:
            return _exceptions.ConflictError(err_msg, response=response, body=body)

        if response.status_code == 422:
            return _exceptions.UnprocessableEntityError(err_msg, response=response, body=body)

        if response.status_code == 429:
            return _exceptions.RateLimitError(err_msg, response=response, body=body)

        if response.status_code >= 500:
            return _exceptions.InternalServerError(err_msg, response=response, body=body)
        return APIStatusError(err_msg, response=response, body=body)


class FluidizeSDKWithRawResponse:
    def __init__(self, client: FluidizeSDK) -> None:
        self.test_connection = test_connection.TestConnectionResourceWithRawResponse(client.test_connection)
        self.candy = candy.CandyResourceWithRawResponse(client.candy)
        self.graph = graph.GraphResourceWithRawResponse(client.graph)
        self.projects = projects.ProjectsResourceWithRawResponse(client.projects)
        self.files = files.FilesResourceWithRawResponse(client.files)
        self.runs = runs.RunsResourceWithRawResponse(client.runs)
        self.auth = auth.AuthResourceWithRawResponse(client.auth)
        self.list_environments = list_environments.ListEnvironmentsResourceWithRawResponse(client.list_environments)
        self.upsert_simulation = upsert_simulation.UpsertSimulationResourceWithRawResponse(client.upsert_simulation)
        self.utils = utils.UtilsResourceWithRawResponse(client.utils)
        self.simulation = simulation.SimulationResourceWithRawResponse(client.simulation)

        self.retrieve_root = to_raw_response_wrapper(
            client.retrieve_root,
        )


class AsyncFluidizeSDKWithRawResponse:
    def __init__(self, client: AsyncFluidizeSDK) -> None:
        self.test_connection = test_connection.AsyncTestConnectionResourceWithRawResponse(client.test_connection)
        self.candy = candy.AsyncCandyResourceWithRawResponse(client.candy)
        self.graph = graph.AsyncGraphResourceWithRawResponse(client.graph)
        self.projects = projects.AsyncProjectsResourceWithRawResponse(client.projects)
        self.files = files.AsyncFilesResourceWithRawResponse(client.files)
        self.runs = runs.AsyncRunsResourceWithRawResponse(client.runs)
        self.auth = auth.AsyncAuthResourceWithRawResponse(client.auth)
        self.list_environments = list_environments.AsyncListEnvironmentsResourceWithRawResponse(
            client.list_environments
        )
        self.upsert_simulation = upsert_simulation.AsyncUpsertSimulationResourceWithRawResponse(
            client.upsert_simulation
        )
        self.utils = utils.AsyncUtilsResourceWithRawResponse(client.utils)
        self.simulation = simulation.AsyncSimulationResourceWithRawResponse(client.simulation)

        self.retrieve_root = async_to_raw_response_wrapper(
            client.retrieve_root,
        )


class FluidizeSDKWithStreamedResponse:
    def __init__(self, client: FluidizeSDK) -> None:
        self.test_connection = test_connection.TestConnectionResourceWithStreamingResponse(client.test_connection)
        self.candy = candy.CandyResourceWithStreamingResponse(client.candy)
        self.graph = graph.GraphResourceWithStreamingResponse(client.graph)
        self.projects = projects.ProjectsResourceWithStreamingResponse(client.projects)
        self.files = files.FilesResourceWithStreamingResponse(client.files)
        self.runs = runs.RunsResourceWithStreamingResponse(client.runs)
        self.auth = auth.AuthResourceWithStreamingResponse(client.auth)
        self.list_environments = list_environments.ListEnvironmentsResourceWithStreamingResponse(
            client.list_environments
        )
        self.upsert_simulation = upsert_simulation.UpsertSimulationResourceWithStreamingResponse(
            client.upsert_simulation
        )
        self.utils = utils.UtilsResourceWithStreamingResponse(client.utils)
        self.simulation = simulation.SimulationResourceWithStreamingResponse(client.simulation)

        self.retrieve_root = to_streamed_response_wrapper(
            client.retrieve_root,
        )


class AsyncFluidizeSDKWithStreamedResponse:
    def __init__(self, client: AsyncFluidizeSDK) -> None:
        self.test_connection = test_connection.AsyncTestConnectionResourceWithStreamingResponse(client.test_connection)
        self.candy = candy.AsyncCandyResourceWithStreamingResponse(client.candy)
        self.graph = graph.AsyncGraphResourceWithStreamingResponse(client.graph)
        self.projects = projects.AsyncProjectsResourceWithStreamingResponse(client.projects)
        self.files = files.AsyncFilesResourceWithStreamingResponse(client.files)
        self.runs = runs.AsyncRunsResourceWithStreamingResponse(client.runs)
        self.auth = auth.AsyncAuthResourceWithStreamingResponse(client.auth)
        self.list_environments = list_environments.AsyncListEnvironmentsResourceWithStreamingResponse(
            client.list_environments
        )
        self.upsert_simulation = upsert_simulation.AsyncUpsertSimulationResourceWithStreamingResponse(
            client.upsert_simulation
        )
        self.utils = utils.AsyncUtilsResourceWithStreamingResponse(client.utils)
        self.simulation = simulation.AsyncSimulationResourceWithStreamingResponse(client.simulation)

        self.retrieve_root = async_to_streamed_response_wrapper(
            client.retrieve_root,
        )


Client = FluidizeSDK

AsyncClient = AsyncFluidizeSDK



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import os
from typing import Any, cast

import pytest

from tests.utils import assert_matches_type
from fluidize_sdk import FluidizeSDK, AsyncFluidizeSDK
from fluidize_sdk.types import (
    GraphEdge,
    GraphNode,
    Parameter,
    GraphRetrieveResponse,
    GraphGetParametersResponse,
    GraphSetParametersResponse,
)

base_url = os.environ.get("TEST_API_BASE_URL", "http://127.0.0.1:4010")


class TestGraph:
    parametrize = pytest.mark.parametrize("client", [False, True], indirect=True, ids=["loose", "strict"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_retrieve(self, client: FluidizeSDK) -> None:
        graph = client.graph.retrieve(
            id="id",
        )
        assert_matches_type(GraphRetrieveResponse, graph, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_retrieve_with_all_params(self, client: FluidizeSDK) -> None:
        graph = client.graph.retrieve(
            id="id",
            description="description",
            label="label",
            location="location",
            metadata_version="metadata_version",
            status="status",
        )
        assert_matches_type(GraphRetrieveResponse, graph, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_raw_response_retrieve(self, client: FluidizeSDK) -> None:
        response = client.graph.with_raw_response.retrieve(
            id="id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        graph = response.parse()
        assert_matches_type(GraphRetrieveResponse, graph, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_streaming_response_retrieve(self, client: FluidizeSDK) -> None:
        with client.graph.with_streaming_response.retrieve(
            id="id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            graph = response.parse()
            assert_matches_type(GraphRetrieveResponse, graph, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_delete_edge(self, client: FluidizeSDK) -> None:
        graph = client.graph.delete_edge(
            edge_id="edge_id",
            id="id",
        )
        assert_matches_type(object, graph, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_delete_edge_with_all_params(self, client: FluidizeSDK) -> None:
        graph = client.graph.delete_edge(
            edge_id="edge_id",
            id="id",
            description="description",
            label="label",
            location="location",
            metadata_version="metadata_version",
            status="status",
        )
        assert_matches_type(object, graph, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_raw_response_delete_edge(self, client: FluidizeSDK) -> None:
        response = client.graph.with_raw_response.delete_edge(
            edge_id="edge_id",
            id="id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        graph = response.parse()
        assert_matches_type(object, graph, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_streaming_response_delete_edge(self, client: FluidizeSDK) -> None:
        with client.graph.with_streaming_response.delete_edge(
            edge_id="edge_id",
            id="id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            graph = response.parse()
            assert_matches_type(object, graph, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_path_params_delete_edge(self, client: FluidizeSDK) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `edge_id` but received ''"):
            client.graph.with_raw_response.delete_edge(
                edge_id="",
                id="id",
            )

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_delete_node(self, client: FluidizeSDK) -> None:
        graph = client.graph.delete_node(
            node_id="node_id",
            id="id",
        )
        assert_matches_type(object, graph, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_delete_node_with_all_params(self, client: FluidizeSDK) -> None:
        graph = client.graph.delete_node(
            node_id="node_id",
            id="id",
            description="description",
            label="label",
            location="location",
            metadata_version="metadata_version",
            status="status",
        )
        assert_matches_type(object, graph, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_raw_response_delete_node(self, client: FluidizeSDK) -> None:
        response = client.graph.with_raw_response.delete_node(
            node_id="node_id",
            id="id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        graph = response.parse()
        assert_matches_type(object, graph, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_streaming_response_delete_node(self, client: FluidizeSDK) -> None:
        with client.graph.with_streaming_response.delete_node(
            node_id="node_id",
            id="id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            graph = response.parse()
            assert_matches_type(object, graph, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_path_params_delete_node(self, client: FluidizeSDK) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `node_id` but received ''"):
            client.graph.with_raw_response.delete_node(
                node_id="",
                id="id",
            )

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_get_parameters(self, client: FluidizeSDK) -> None:
        graph = client.graph.get_parameters(
            node_id="node_id",
            id="id",
        )
        assert_matches_type(GraphGetParametersResponse, graph, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_get_parameters_with_all_params(self, client: FluidizeSDK) -> None:
        graph = client.graph.get_parameters(
            node_id="node_id",
            id="id",
            description="description",
            label="label",
            location="location",
            metadata_version="metadata_version",
            status="status",
        )
        assert_matches_type(GraphGetParametersResponse, graph, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_raw_response_get_parameters(self, client: FluidizeSDK) -> None:
        response = client.graph.with_raw_response.get_parameters(
            node_id="node_id",
            id="id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        graph = response.parse()
        assert_matches_type(GraphGetParametersResponse, graph, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_streaming_response_get_parameters(self, client: FluidizeSDK) -> None:
        with client.graph.with_streaming_response.get_parameters(
            node_id="node_id",
            id="id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            graph = response.parse()
            assert_matches_type(GraphGetParametersResponse, graph, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_path_params_get_parameters(self, client: FluidizeSDK) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `node_id` but received ''"):
            client.graph.with_raw_response.get_parameters(
                node_id="",
                id="id",
            )

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_insert_node(self, client: FluidizeSDK) -> None:
        graph = client.graph.insert_node(
            node={
                "id": "id",
                "data": {"label": "label"},
                "position": {
                    "x": 0,
                    "y": 0,
                },
                "type": "type",
            },
            project={"id": "id"},
        )
        assert_matches_type(GraphNode, graph, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_insert_node_with_all_params(self, client: FluidizeSDK) -> None:
        graph = client.graph.insert_node(
            node={
                "id": "id",
                "data": {
                    "label": "label",
                    "simulation_id": "simulation_id",
                },
                "position": {
                    "x": 0,
                    "y": 0,
                },
                "type": "type",
            },
            project={
                "id": "id",
                "description": "description",
                "label": "label",
                "location": "location",
                "metadata_version": "metadata_version",
                "status": "status",
            },
            sim_global=True,
        )
        assert_matches_type(GraphNode, graph, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_raw_response_insert_node(self, client: FluidizeSDK) -> None:
        response = client.graph.with_raw_response.insert_node(
            node={
                "id": "id",
                "data": {"label": "label"},
                "position": {
                    "x": 0,
                    "y": 0,
                },
                "type": "type",
            },
            project={"id": "id"},
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        graph = response.parse()
        assert_matches_type(GraphNode, graph, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_streaming_response_insert_node(self, client: FluidizeSDK) -> None:
        with client.graph.with_streaming_response.insert_node(
            node={
                "id": "id",
                "data": {"label": "label"},
                "position": {
                    "x": 0,
                    "y": 0,
                },
                "type": "type",
            },
            project={"id": "id"},
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            graph = response.parse()
            assert_matches_type(GraphNode, graph, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_set_parameters(self, client: FluidizeSDK) -> None:
        graph = client.graph.set_parameters(
            node_id="node_id",
            id="id",
            body=[
                {
                    "description": "description",
                    "label": "label",
                    "name": "name",
                    "type": "type",
                    "value": "value",
                }
            ],
        )
        assert_matches_type(GraphSetParametersResponse, graph, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_set_parameters_with_all_params(self, client: FluidizeSDK) -> None:
        graph = client.graph.set_parameters(
            node_id="node_id",
            id="id",
            body=[
                {
                    "description": "description",
                    "label": "label",
                    "name": "name",
                    "type": "type",
                    "value": "value",
                    "latex": "latex",
                    "location": ["string"],
                    "options": [
                        {
                            "label": "label",
                            "value": "value",
                        }
                    ],
                    "scope": "scope",
                }
            ],
            description="description",
            label="label",
            location="location",
            metadata_version="metadata_version",
            status="status",
        )
        assert_matches_type(GraphSetParametersResponse, graph, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_raw_response_set_parameters(self, client: FluidizeSDK) -> None:
        response = client.graph.with_raw_response.set_parameters(
            node_id="node_id",
            id="id",
            body=[
                {
                    "description": "description",
                    "label": "label",
                    "name": "name",
                    "type": "type",
                    "value": "value",
                }
            ],
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        graph = response.parse()
        assert_matches_type(GraphSetParametersResponse, graph, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_streaming_response_set_parameters(self, client: FluidizeSDK) -> None:
        with client.graph.with_streaming_response.set_parameters(
            node_id="node_id",
            id="id",
            body=[
                {
                    "description": "description",
                    "label": "label",
                    "name": "name",
                    "type": "type",
                    "value": "value",
                }
            ],
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            graph = response.parse()
            assert_matches_type(GraphSetParametersResponse, graph, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_path_params_set_parameters(self, client: FluidizeSDK) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `node_id` but received ''"):
            client.graph.with_raw_response.set_parameters(
                node_id="",
                id="id",
                body=[
                    {
                        "description": "description",
                        "label": "label",
                        "name": "name",
                        "type": "type",
                        "value": "value",
                    }
                ],
            )

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_sync(self, client: FluidizeSDK) -> None:
        graph = client.graph.sync(
            id="id",
        )
        assert_matches_type(object, graph, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_sync_with_all_params(self, client: FluidizeSDK) -> None:
        graph = client.graph.sync(
            id="id",
            description="description",
            label="label",
            location="location",
            metadata_version="metadata_version",
            status="status",
        )
        assert_matches_type(object, graph, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_raw_response_sync(self, client: FluidizeSDK) -> None:
        response = client.graph.with_raw_response.sync(
            id="id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        graph = response.parse()
        assert_matches_type(object, graph, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_streaming_response_sync(self, client: FluidizeSDK) -> None:
        with client.graph.with_streaming_response.sync(
            id="id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            graph = response.parse()
            assert_matches_type(object, graph, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_update_node_position(self, client: FluidizeSDK) -> None:
        graph = client.graph.update_node_position(
            query_id="id",
            body_id="id",
            data={"label": "label"},
            position={
                "x": 0,
                "y": 0,
            },
            type="type",
        )
        assert_matches_type(GraphNode, graph, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_update_node_position_with_all_params(self, client: FluidizeSDK) -> None:
        graph = client.graph.update_node_position(
            query_id="id",
            body_id="id",
            data={
                "label": "label",
                "simulation_id": "simulation_id",
            },
            position={
                "x": 0,
                "y": 0,
            },
            type="type",
            description="description",
            label="label",
            location="location",
            metadata_version="metadata_version",
            status="status",
        )
        assert_matches_type(GraphNode, graph, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_raw_response_update_node_position(self, client: FluidizeSDK) -> None:
        response = client.graph.with_raw_response.update_node_position(
            query_id="id",
            body_id="id",
            data={"label": "label"},
            position={
                "x": 0,
                "y": 0,
            },
            type="type",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        graph = response.parse()
        assert_matches_type(GraphNode, graph, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_streaming_response_update_node_position(self, client: FluidizeSDK) -> None:
        with client.graph.with_streaming_response.update_node_position(
            query_id="id",
            body_id="id",
            data={"label": "label"},
            position={
                "x": 0,
                "y": 0,
            },
            type="type",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            graph = response.parse()
            assert_matches_type(GraphNode, graph, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_upsert_edge(self, client: FluidizeSDK) -> None:
        graph = client.graph.upsert_edge(
            query_id="id",
            body_id="id",
            source="source",
            target="target",
            type="type",
        )
        assert_matches_type(GraphEdge, graph, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_upsert_edge_with_all_params(self, client: FluidizeSDK) -> None:
        graph = client.graph.upsert_edge(
            query_id="id",
            body_id="id",
            source="source",
            target="target",
            type="type",
            description="description",
            label="label",
            location="location",
            metadata_version="metadata_version",
            status="status",
        )
        assert_matches_type(GraphEdge, graph, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_raw_response_upsert_edge(self, client: FluidizeSDK) -> None:
        response = client.graph.with_raw_response.upsert_edge(
            query_id="id",
            body_id="id",
            source="source",
            target="target",
            type="type",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        graph = response.parse()
        assert_matches_type(GraphEdge, graph, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_streaming_response_upsert_edge(self, client: FluidizeSDK) -> None:
        with client.graph.with_streaming_response.upsert_edge(
            query_id="id",
            body_id="id",
            source="source",
            target="target",
            type="type",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            graph = response.parse()
            assert_matches_type(GraphEdge, graph, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_upsert_parameter(self, client: FluidizeSDK) -> None:
        graph = client.graph.upsert_parameter(
            path="path",
            description="description",
            label="label",
            name="name",
            type="type",
            value="value",
        )
        assert_matches_type(Parameter, graph, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_upsert_parameter_with_all_params(self, client: FluidizeSDK) -> None:
        graph = client.graph.upsert_parameter(
            path="path",
            description="description",
            label="label",
            name="name",
            type="type",
            value="value",
            latex="latex",
            location=["string"],
            options=[
                {
                    "label": "label",
                    "value": "value",
                }
            ],
            scope="scope",
        )
        assert_matches_type(Parameter, graph, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_raw_response_upsert_parameter(self, client: FluidizeSDK) -> None:
        response = client.graph.with_raw_response.upsert_parameter(
            path="path",
            description="description",
            label="label",
            name="name",
            type="type",
            value="value",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        graph = response.parse()
        assert_matches_type(Parameter, graph, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_streaming_response_upsert_parameter(self, client: FluidizeSDK) -> None:
        with client.graph.with_streaming_response.upsert_parameter(
            path="path",
            description="description",
            label="label",
            name="name",
            type="type",
            value="value",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            graph = response.parse()
            assert_matches_type(Parameter, graph, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_path_params_upsert_parameter(self, client: FluidizeSDK) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `path` but received ''"):
            client.graph.with_raw_response.upsert_parameter(
                path="",
                description="description",
                label="label",
                name="name",
                type="type",
                value="value",
            )


class TestAsyncGraph:
    parametrize = pytest.mark.parametrize(
        "async_client", [False, True, {"http_client": "aiohttp"}], indirect=True, ids=["loose", "strict", "aiohttp"]
    )

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_retrieve(self, async_client: AsyncFluidizeSDK) -> None:
        graph = await async_client.graph.retrieve(
            id="id",
        )
        assert_matches_type(GraphRetrieveResponse, graph, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_retrieve_with_all_params(self, async_client: AsyncFluidizeSDK) -> None:
        graph = await async_client.graph.retrieve(
            id="id",
            description="description",
            label="label",
            location="location",
            metadata_version="metadata_version",
            status="status",
        )
        assert_matches_type(GraphRetrieveResponse, graph, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_raw_response_retrieve(self, async_client: AsyncFluidizeSDK) -> None:
        response = await async_client.graph.with_raw_response.retrieve(
            id="id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        graph = await response.parse()
        assert_matches_type(GraphRetrieveResponse, graph, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_streaming_response_retrieve(self, async_client: AsyncFluidizeSDK) -> None:
        async with async_client.graph.with_streaming_response.retrieve(
            id="id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            graph = await response.parse()
            assert_matches_type(GraphRetrieveResponse, graph, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_delete_edge(self, async_client: AsyncFluidizeSDK) -> None:
        graph = await async_client.graph.delete_edge(
            edge_id="edge_id",
            id="id",
        )
        assert_matches_type(object, graph, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_delete_edge_with_all_params(self, async_client: AsyncFluidizeSDK) -> None:
        graph = await async_client.graph.delete_edge(
            edge_id="edge_id",
            id="id",
            description="description",
            label="label",
            location="location",
            metadata_version="metadata_version",
            status="status",
        )
        assert_matches_type(object, graph, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_raw_response_delete_edge(self, async_client: AsyncFluidizeSDK) -> None:
        response = await async_client.graph.with_raw_response.delete_edge(
            edge_id="edge_id",
            id="id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        graph = await response.parse()
        assert_matches_type(object, graph, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_streaming_response_delete_edge(self, async_client: AsyncFluidizeSDK) -> None:
        async with async_client.graph.with_streaming_response.delete_edge(
            edge_id="edge_id",
            id="id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            graph = await response.parse()
            assert_matches_type(object, graph, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_path_params_delete_edge(self, async_client: AsyncFluidizeSDK) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `edge_id` but received ''"):
            await async_client.graph.with_raw_response.delete_edge(
                edge_id="",
                id="id",
            )

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_delete_node(self, async_client: AsyncFluidizeSDK) -> None:
        graph = await async_client.graph.delete_node(
            node_id="node_id",
            id="id",
        )
        assert_matches_type(object, graph, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_delete_node_with_all_params(self, async_client: AsyncFluidizeSDK) -> None:
        graph = await async_client.graph.delete_node(
            node_id="node_id",
            id="id",
            description="description",
            label="label",
            location="location",
            metadata_version="metadata_version",
            status="status",
        )
        assert_matches_type(object, graph, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_raw_response_delete_node(self, async_client: AsyncFluidizeSDK) -> None:
        response = await async_client.graph.with_raw_response.delete_node(
            node_id="node_id",
            id="id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        graph = await response.parse()
        assert_matches_type(object, graph, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_streaming_response_delete_node(self, async_client: AsyncFluidizeSDK) -> None:
        async with async_client.graph.with_streaming_response.delete_node(
            node_id="node_id",
            id="id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            graph = await response.parse()
            assert_matches_type(object, graph, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_path_params_delete_node(self, async_client: AsyncFluidizeSDK) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `node_id` but received ''"):
            await async_client.graph.with_raw_response.delete_node(
                node_id="",
                id="id",
            )

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_get_parameters(self, async_client: AsyncFluidizeSDK) -> None:
        graph = await async_client.graph.get_parameters(
            node_id="node_id",
            id="id",
        )
        assert_matches_type(GraphGetParametersResponse, graph, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_get_parameters_with_all_params(self, async_client: AsyncFluidizeSDK) -> None:
        graph = await async_client.graph.get_parameters(
            node_id="node_id",
            id="id",
            description="description",
            label="label",
            location="location",
            metadata_version="metadata_version",
            status="status",
        )
        assert_matches_type(GraphGetParametersResponse, graph, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_raw_response_get_parameters(self, async_client: AsyncFluidizeSDK) -> None:
        response = await async_client.graph.with_raw_response.get_parameters(
            node_id="node_id",
            id="id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        graph = await response.parse()
        assert_matches_type(GraphGetParametersResponse, graph, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_streaming_response_get_parameters(self, async_client: AsyncFluidizeSDK) -> None:
        async with async_client.graph.with_streaming_response.get_parameters(
            node_id="node_id",
            id="id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            graph = await response.parse()
            assert_matches_type(GraphGetParametersResponse, graph, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_path_params_get_parameters(self, async_client: AsyncFluidizeSDK) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `node_id` but received ''"):
            await async_client.graph.with_raw_response.get_parameters(
                node_id="",
                id="id",
            )

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_insert_node(self, async_client: AsyncFluidizeSDK) -> None:
        graph = await async_client.graph.insert_node(
            node={
                "id": "id",
                "data": {"label": "label"},
                "position": {
                    "x": 0,
                    "y": 0,
                },
                "type": "type",
            },
            project={"id": "id"},
        )
        assert_matches_type(GraphNode, graph, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_insert_node_with_all_params(self, async_client: AsyncFluidizeSDK) -> None:
        graph = await async_client.graph.insert_node(
            node={
                "id": "id",
                "data": {
                    "label": "label",
                    "simulation_id": "simulation_id",
                },
                "position": {
                    "x": 0,
                    "y": 0,
                },
                "type": "type",
            },
            project={
                "id": "id",
                "description": "description",
                "label": "label",
                "location": "location",
                "metadata_version": "metadata_version",
                "status": "status",
            },
            sim_global=True,
        )
        assert_matches_type(GraphNode, graph, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_raw_response_insert_node(self, async_client: AsyncFluidizeSDK) -> None:
        response = await async_client.graph.with_raw_response.insert_node(
            node={
                "id": "id",
                "data": {"label": "label"},
                "position": {
                    "x": 0,
                    "y": 0,
                },
                "type": "type",
            },
            project={"id": "id"},
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        graph = await response.parse()
        assert_matches_type(GraphNode, graph, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_streaming_response_insert_node(self, async_client: AsyncFluidizeSDK) -> None:
        async with async_client.graph.with_streaming_response.insert_node(
            node={
                "id": "id",
                "data": {"label": "label"},
                "position": {
                    "x": 0,
                    "y": 0,
                },
                "type": "type",
            },
            project={"id": "id"},
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            graph = await response.parse()
            assert_matches_type(GraphNode, graph, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_set_parameters(self, async_client: AsyncFluidizeSDK) -> None:
        graph = await async_client.graph.set_parameters(
            node_id="node_id",
            id="id",
            body=[
                {
                    "description": "description",
                    "label": "label",
                    "name": "name",
                    "type": "type",
                    "value": "value",
                }
            ],
        )
        assert_matches_type(GraphSetParametersResponse, graph, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_set_parameters_with_all_params(self, async_client: AsyncFluidizeSDK) -> None:
        graph = await async_client.graph.set_parameters(
            node_id="node_id",
            id="id",
            body=[
                {
                    "description": "description",
                    "label": "label",
                    "name": "name",
                    "type": "type",
                    "value": "value",
                    "latex": "latex",
                    "location": ["string"],
                    "options": [
                        {
                            "label": "label",
                            "value": "value",
                        }
                    ],
                    "scope": "scope",
                }
            ],
            description="description",
            label="label",
            location="location",
            metadata_version="metadata_version",
            status="status",
        )
        assert_matches_type(GraphSetParametersResponse, graph, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_raw_response_set_parameters(self, async_client: AsyncFluidizeSDK) -> None:
        response = await async_client.graph.with_raw_response.set_parameters(
            node_id="node_id",
            id="id",
            body=[
                {
                    "description": "description",
                    "label": "label",
                    "name": "name",
                    "type": "type",
                    "value": "value",
                }
            ],
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        graph = await response.parse()
        assert_matches_type(GraphSetParametersResponse, graph, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_streaming_response_set_parameters(self, async_client: AsyncFluidizeSDK) -> None:
        async with async_client.graph.with_streaming_response.set_parameters(
            node_id="node_id",
            id="id",
            body=[
                {
                    "description": "description",
                    "label": "label",
                    "name": "name",
                    "type": "type",
                    "value": "value",
                }
            ],
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            graph = await response.parse()
            assert_matches_type(GraphSetParametersResponse, graph, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_path_params_set_parameters(self, async_client: AsyncFluidizeSDK) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `node_id` but received ''"):
            await async_client.graph.with_raw_response.set_parameters(
                node_id="",
                id="id",
                body=[
                    {
                        "description": "description",
                        "label": "label",
                        "name": "name",
                        "type": "type",
                        "value": "value",
                    }
                ],
            )

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_sync(self, async_client: AsyncFluidizeSDK) -> None:
        graph = await async_client.graph.sync(
            id="id",
        )
        assert_matches_type(object, graph, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_sync_with_all_params(self, async_client: AsyncFluidizeSDK) -> None:
        graph = await async_client.graph.sync(
            id="id",
            description="description",
            label="label",
            location="location",
            metadata_version="metadata_version",
            status="status",
        )
        assert_matches_type(object, graph, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_raw_response_sync(self, async_client: AsyncFluidizeSDK) -> None:
        response = await async_client.graph.with_raw_response.sync(
            id="id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        graph = await response.parse()
        assert_matches_type(object, graph, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_streaming_response_sync(self, async_client: AsyncFluidizeSDK) -> None:
        async with async_client.graph.with_streaming_response.sync(
            id="id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            graph = await response.parse()
            assert_matches_type(object, graph, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_update_node_position(self, async_client: AsyncFluidizeSDK) -> None:
        graph = await async_client.graph.update_node_position(
            query_id="id",
            body_id="id",
            data={"label": "label"},
            position={
                "x": 0,
                "y": 0,
            },
            type="type",
        )
        assert_matches_type(GraphNode, graph, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_update_node_position_with_all_params(self, async_client: AsyncFluidizeSDK) -> None:
        graph = await async_client.graph.update_node_position(
            query_id="id",
            body_id="id",
            data={
                "label": "label",
                "simulation_id": "simulation_id",
            },
            position={
                "x": 0,
                "y": 0,
            },
            type="type",
            description="description",
            label="label",
            location="location",
            metadata_version="metadata_version",
            status="status",
        )
        assert_matches_type(GraphNode, graph, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_raw_response_update_node_position(self, async_client: AsyncFluidizeSDK) -> None:
        response = await async_client.graph.with_raw_response.update_node_position(
            query_id="id",
            body_id="id",
            data={"label": "label"},
            position={
                "x": 0,
                "y": 0,
            },
            type="type",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        graph = await response.parse()
        assert_matches_type(GraphNode, graph, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_streaming_response_update_node_position(self, async_client: AsyncFluidizeSDK) -> None:
        async with async_client.graph.with_streaming_response.update_node_position(
            query_id="id",
            body_id="id",
            data={"label": "label"},
            position={
                "x": 0,
                "y": 0,
            },
            type="type",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            graph = await response.parse()
            assert_matches_type(GraphNode, graph, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_upsert_edge(self, async_client: AsyncFluidizeSDK) -> None:
        graph = await async_client.graph.upsert_edge(
            query_id="id",
            body_id="id",
            source="source",
            target="target",
            type="type",
        )
        assert_matches_type(GraphEdge, graph, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_upsert_edge_with_all_params(self, async_client: AsyncFluidizeSDK) -> None:
        graph = await async_client.graph.upsert_edge(
            query_id="id",
            body_id="id",
            source="source",
            target="target",
            type="type",
            description="description",
            label="label",
            location="location",
            metadata_version="metadata_version",
            status="status",
        )
        assert_matches_type(GraphEdge, graph, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_raw_response_upsert_edge(self, async_client: AsyncFluidizeSDK) -> None:
        response = await async_client.graph.with_raw_response.upsert_edge(
            query_id="id",
            body_id="id",
            source="source",
            target="target",
            type="type",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        graph = await response.parse()
        assert_matches_type(GraphEdge, graph, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_streaming_response_upsert_edge(self, async_client: AsyncFluidizeSDK) -> None:
        async with async_client.graph.with_streaming_response.upsert_edge(
            query_id="id",
            body_id="id",
            source="source",
            target="target",
            type="type",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            graph = await response.parse()
            assert_matches_type(GraphEdge, graph, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_upsert_parameter(self, async_client: AsyncFluidizeSDK) -> None:
        graph = await async_client.graph.upsert_parameter(
            path="path",
            description="description",
            label="label",
            name="name",
            type="type",
            value="value",
        )
        assert_matches_type(Parameter, graph, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_upsert_parameter_with_all_params(self, async_client: AsyncFluidizeSDK) -> None:
        graph = await async_client.graph.upsert_parameter(
            path="path",
            description="description",
            label="label",
            name="name",
            type="type",
            value="value",
            latex="latex",
            location=["string"],
            options=[
                {
                    "label": "label",
                    "value": "value",
                }
            ],
            scope="scope",
        )
        assert_matches_type(Parameter, graph, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_raw_response_upsert_parameter(self, async_client: AsyncFluidizeSDK) -> None:
        response = await async_client.graph.with_raw_response.upsert_parameter(
            path="path",
            description="description",
            label="label",
            name="name",
            type="type",
            value="value",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        graph = await response.parse()
        assert_matches_type(Parameter, graph, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_streaming_response_upsert_parameter(self, async_client: AsyncFluidizeSDK) -> None:
        async with async_client.graph.with_streaming_response.upsert_parameter(
            path="path",
            description="description",
            label="label",
            name="name",
            type="type",
            value="value",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            graph = await response.parse()
            assert_matches_type(Parameter, graph, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_path_params_upsert_parameter(self, async_client: AsyncFluidizeSDK) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `path` but received ''"):
            await async_client.graph.with_raw_response.upsert_parameter(
                path="",
                description="description",
                label="label",
                name="name",
                type="type",
                value="value",
            )



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import httpx

from .ssh import (
    SSHResource,
    AsyncSSHResource,
    SSHResourceWithRawResponse,
    AsyncSSHResourceWithRawResponse,
    SSHResourceWithStreamingResponse,
    AsyncSSHResourceWithStreamingResponse,
)
from ...types import auth_session_login_params
from ..._types import NOT_GIVEN, Body, Query, Headers, NoneType, NotGiven
from ..._utils import maybe_transform, async_maybe_transform
from ..._compat import cached_property
from ..._resource import SyncAPIResource, AsyncAPIResource
from ..._response import (
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    async_to_streamed_response_wrapper,
)
from ..._base_client import make_request_options
from ...types.auth_session_login_response import AuthSessionLoginResponse

__all__ = ["AuthResource", "AsyncAuthResource"]


class AuthResource(SyncAPIResource):
    @cached_property
    def ssh(self) -> SSHResource:
        return SSHResource(self._client)

    @cached_property
    def with_raw_response(self) -> AuthResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/Fluidize-Inc/fluidize-python-sdk#accessing-raw-response-data-eg-headers
        """
        return AuthResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AuthResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/Fluidize-Inc/fluidize-python-sdk#with_streaming_response
        """
        return AuthResourceWithStreamingResponse(self)

    def logout(
        self,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> None:
        """Clears the session cookie upon user logout."""
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return self._post(
            "/auth/logout",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )

    def session_login(
        self,
        *,
        id_token: str,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> AuthSessionLoginResponse:
        """
        Handles user session login.

        This endpoint receives an ID token from the client, verifies it, and then either
        retrieves the existing user or creates a new one in the backend database. It
        also sets a secure, HttpOnly Firebase session cookie.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return self._post(
            "/auth/session-login",
            body=maybe_transform({"id_token": id_token}, auth_session_login_params.AuthSessionLoginParams),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=AuthSessionLoginResponse,
        )


class AsyncAuthResource(AsyncAPIResource):
    @cached_property
    def ssh(self) -> AsyncSSHResource:
        return AsyncSSHResource(self._client)

    @cached_property
    def with_raw_response(self) -> AsyncAuthResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/Fluidize-Inc/fluidize-python-sdk#accessing-raw-response-data-eg-headers
        """
        return AsyncAuthResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncAuthResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/Fluidize-Inc/fluidize-python-sdk#with_streaming_response
        """
        return AsyncAuthResourceWithStreamingResponse(self)

    async def logout(
        self,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> None:
        """Clears the session cookie upon user logout."""
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return await self._post(
            "/auth/logout",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )

    async def session_login(
        self,
        *,
        id_token: str,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> AuthSessionLoginResponse:
        """
        Handles user session login.

        This endpoint receives an ID token from the client, verifies it, and then either
        retrieves the existing user or creates a new one in the backend database. It
        also sets a secure, HttpOnly Firebase session cookie.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return await self._post(
            "/auth/session-login",
            body=await async_maybe_transform({"id_token": id_token}, auth_session_login_params.AuthSessionLoginParams),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=AuthSessionLoginResponse,
        )


class AuthResourceWithRawResponse:
    def __init__(self, auth: AuthResource) -> None:
        self._auth = auth

        self.logout = to_raw_response_wrapper(
            auth.logout,
        )
        self.session_login = to_raw_response_wrapper(
            auth.session_login,
        )

    @cached_property
    def ssh(self) -> SSHResourceWithRawResponse:
        return SSHResourceWithRawResponse(self._auth.ssh)


class AsyncAuthResourceWithRawResponse:
    def __init__(self, auth: AsyncAuthResource) -> None:
        self._auth = auth

        self.logout = async_to_raw_response_wrapper(
            auth.logout,
        )
        self.session_login = async_to_raw_response_wrapper(
            auth.session_login,
        )

    @cached_property
    def ssh(self) -> AsyncSSHResourceWithRawResponse:
        return AsyncSSHResourceWithRawResponse(self._auth.ssh)


class AuthResourceWithStreamingResponse:
    def __init__(self, auth: AuthResource) -> None:
        self._auth = auth

        self.logout = to_streamed_response_wrapper(
            auth.logout,
        )
        self.session_login = to_streamed_response_wrapper(
            auth.session_login,
        )

    @cached_property
    def ssh(self) -> SSHResourceWithStreamingResponse:
        return SSHResourceWithStreamingResponse(self._auth.ssh)


class AsyncAuthResourceWithStreamingResponse:
    def __init__(self, auth: AsyncAuthResource) -> None:
        self._auth = auth

        self.logout = async_to_streamed_response_wrapper(
            auth.logout,
        )
        self.session_login = async_to_streamed_response_wrapper(
            auth.session_login,
        )

    @cached_property
    def ssh(self) -> AsyncSSHResourceWithStreamingResponse:
        return AsyncSSHResourceWithStreamingResponse(self._auth.ssh)



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Optional
from typing_extensions import Required, Annotated, TypedDict

from .._utils import PropertyInfo

__all__ = ["GraphUpdateNodePositionParams", "Data", "Position"]


class GraphUpdateNodePositionParams(TypedDict, total=False):
    query_id: Required[Annotated[str, PropertyInfo(alias="id")]]

    body_id: Required[Annotated[str, PropertyInfo(alias="id")]]

    data: Required[Data]
    """Extra metadata for a node."""

    position: Required[Position]
    """Position of a node in layout space."""

    type: Required[str]

    description: str

    label: str

    location: str

    metadata_version: str

    status: str


class Data(TypedDict, total=False):
    label: Required[str]

    simulation_id: Optional[str]


class Position(TypedDict, total=False):
    x: Required[float]

    y: Required[float]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import os
from typing import Any, cast

import pytest

from tests.utils import assert_matches_type
from fluidize_sdk import FluidizeSDK, AsyncFluidizeSDK
from fluidize_sdk.types import UpsertSimulationCreateResponse

base_url = os.environ.get("TEST_API_BASE_URL", "http://127.0.0.1:4010")


class TestUpsertSimulation:
    parametrize = pytest.mark.parametrize("client", [False, True], indirect=True, ids=["loose", "strict"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_create(self, client: FluidizeSDK) -> None:
        upsert_simulation = client.upsert_simulation.create(
            container_image="container_image",
            environment_variables=[
                {
                    "key": "key",
                    "value": "value",
                }
            ],
            name="name",
            package_managers=[
                {
                    "name": "name",
                    "packages": ["string"],
                    "version": "version",
                }
            ],
            post_install_script="post_install_script",
        )
        assert_matches_type(UpsertSimulationCreateResponse, upsert_simulation, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_raw_response_create(self, client: FluidizeSDK) -> None:
        response = client.upsert_simulation.with_raw_response.create(
            container_image="container_image",
            environment_variables=[
                {
                    "key": "key",
                    "value": "value",
                }
            ],
            name="name",
            package_managers=[
                {
                    "name": "name",
                    "packages": ["string"],
                    "version": "version",
                }
            ],
            post_install_script="post_install_script",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        upsert_simulation = response.parse()
        assert_matches_type(UpsertSimulationCreateResponse, upsert_simulation, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_streaming_response_create(self, client: FluidizeSDK) -> None:
        with client.upsert_simulation.with_streaming_response.create(
            container_image="container_image",
            environment_variables=[
                {
                    "key": "key",
                    "value": "value",
                }
            ],
            name="name",
            package_managers=[
                {
                    "name": "name",
                    "packages": ["string"],
                    "version": "version",
                }
            ],
            post_install_script="post_install_script",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            upsert_simulation = response.parse()
            assert_matches_type(UpsertSimulationCreateResponse, upsert_simulation, path=["response"])

        assert cast(Any, response.is_closed) is True


class TestAsyncUpsertSimulation:
    parametrize = pytest.mark.parametrize(
        "async_client", [False, True, {"http_client": "aiohttp"}], indirect=True, ids=["loose", "strict", "aiohttp"]
    )

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_create(self, async_client: AsyncFluidizeSDK) -> None:
        upsert_simulation = await async_client.upsert_simulation.create(
            container_image="container_image",
            environment_variables=[
                {
                    "key": "key",
                    "value": "value",
                }
            ],
            name="name",
            package_managers=[
                {
                    "name": "name",
                    "packages": ["string"],
                    "version": "version",
                }
            ],
            post_install_script="post_install_script",
        )
        assert_matches_type(UpsertSimulationCreateResponse, upsert_simulation, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_raw_response_create(self, async_client: AsyncFluidizeSDK) -> None:
        response = await async_client.upsert_simulation.with_raw_response.create(
            container_image="container_image",
            environment_variables=[
                {
                    "key": "key",
                    "value": "value",
                }
            ],
            name="name",
            package_managers=[
                {
                    "name": "name",
                    "packages": ["string"],
                    "version": "version",
                }
            ],
            post_install_script="post_install_script",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        upsert_simulation = await response.parse()
        assert_matches_type(UpsertSimulationCreateResponse, upsert_simulation, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_streaming_response_create(self, async_client: AsyncFluidizeSDK) -> None:
        async with async_client.upsert_simulation.with_streaming_response.create(
            container_image="container_image",
            environment_variables=[
                {
                    "key": "key",
                    "value": "value",
                }
            ],
            name="name",
            package_managers=[
                {
                    "name": "name",
                    "packages": ["string"],
                    "version": "version",
                }
            ],
            post_install_script="post_install_script",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            upsert_simulation = await response.parse()
            assert_matches_type(UpsertSimulationCreateResponse, upsert_simulation, path=["response"])

        assert cast(Any, response.is_closed) is True



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from .retrieval_mode import RetrievalMode as RetrievalMode
from .retrieval_mode_update_params import RetrievalModeUpdateParams as RetrievalModeUpdateParams



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import List, Iterable, Optional
from typing_extensions import Required, TypedDict

__all__ = ["ParameterParam", "Option"]


class Option(TypedDict, total=False):
    label: Required[str]

    value: Required[str]


class ParameterParam(TypedDict, total=False):
    description: Required[str]

    label: Required[str]

    name: Required[str]

    type: Required[str]

    value: Required[str]

    latex: Optional[str]

    location: Optional[List[str]]

    options: Optional[Iterable[Option]]

    scope: Optional[str]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import os
from typing import Any, cast

import pytest

from tests.utils import assert_matches_type
from fluidize_sdk import FluidizeSDK, AsyncFluidizeSDK
from fluidize_sdk.types import (
    SignedURL,
    SaveFileResponse,
    FileListDirectoryResponse,
    FileLoadEditorFileResponse,
)

base_url = os.environ.get("TEST_API_BASE_URL", "http://127.0.0.1:4010")


class TestFiles:
    parametrize = pytest.mark.parametrize("client", [False, True], indirect=True, ids=["loose", "strict"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_fetch_download_signed_url(self, client: FluidizeSDK) -> None:
        file = client.files.fetch_download_signed_url(
            "file_path",
        )
        assert_matches_type(SignedURL, file, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_raw_response_fetch_download_signed_url(self, client: FluidizeSDK) -> None:
        response = client.files.with_raw_response.fetch_download_signed_url(
            "file_path",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        file = response.parse()
        assert_matches_type(SignedURL, file, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_streaming_response_fetch_download_signed_url(self, client: FluidizeSDK) -> None:
        with client.files.with_streaming_response.fetch_download_signed_url(
            "file_path",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            file = response.parse()
            assert_matches_type(SignedURL, file, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_path_params_fetch_download_signed_url(self, client: FluidizeSDK) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `file_path` but received ''"):
            client.files.with_raw_response.fetch_download_signed_url(
                "",
            )

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_fetch_upload_signed_url(self, client: FluidizeSDK) -> None:
        file = client.files.fetch_upload_signed_url(
            "file_path",
        )
        assert_matches_type(SignedURL, file, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_raw_response_fetch_upload_signed_url(self, client: FluidizeSDK) -> None:
        response = client.files.with_raw_response.fetch_upload_signed_url(
            "file_path",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        file = response.parse()
        assert_matches_type(SignedURL, file, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_streaming_response_fetch_upload_signed_url(self, client: FluidizeSDK) -> None:
        with client.files.with_streaming_response.fetch_upload_signed_url(
            "file_path",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            file = response.parse()
            assert_matches_type(SignedURL, file, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_path_params_fetch_upload_signed_url(self, client: FluidizeSDK) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `file_path` but received ''"):
            client.files.with_raw_response.fetch_upload_signed_url(
                "",
            )

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_get_project_node_path(self, client: FluidizeSDK) -> None:
        file = client.files.get_project_node_path(
            id="id",
            node_id="node_id",
        )
        assert_matches_type(str, file, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_get_project_node_path_with_all_params(self, client: FluidizeSDK) -> None:
        file = client.files.get_project_node_path(
            id="id",
            node_id="node_id",
            description="description",
            label="label",
            location="location",
            metadata_version="metadata_version",
            status="status",
        )
        assert_matches_type(str, file, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_raw_response_get_project_node_path(self, client: FluidizeSDK) -> None:
        response = client.files.with_raw_response.get_project_node_path(
            id="id",
            node_id="node_id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        file = response.parse()
        assert_matches_type(str, file, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_streaming_response_get_project_node_path(self, client: FluidizeSDK) -> None:
        with client.files.with_streaming_response.get_project_node_path(
            id="id",
            node_id="node_id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            file = response.parse()
            assert_matches_type(str, file, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_get_simulation_path(self, client: FluidizeSDK) -> None:
        file = client.files.get_simulation_path(
            node_id="node_id",
            sim_global=True,
        )
        assert_matches_type(str, file, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_raw_response_get_simulation_path(self, client: FluidizeSDK) -> None:
        response = client.files.with_raw_response.get_simulation_path(
            node_id="node_id",
            sim_global=True,
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        file = response.parse()
        assert_matches_type(str, file, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_streaming_response_get_simulation_path(self, client: FluidizeSDK) -> None:
        with client.files.with_streaming_response.get_simulation_path(
            node_id="node_id",
            sim_global=True,
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            file = response.parse()
            assert_matches_type(str, file, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_list_directory(self, client: FluidizeSDK) -> None:
        file = client.files.list_directory(
            "file_path",
        )
        assert_matches_type(FileListDirectoryResponse, file, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_raw_response_list_directory(self, client: FluidizeSDK) -> None:
        response = client.files.with_raw_response.list_directory(
            "file_path",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        file = response.parse()
        assert_matches_type(FileListDirectoryResponse, file, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_streaming_response_list_directory(self, client: FluidizeSDK) -> None:
        with client.files.with_streaming_response.list_directory(
            "file_path",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            file = response.parse()
            assert_matches_type(FileListDirectoryResponse, file, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_path_params_list_directory(self, client: FluidizeSDK) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `file_path` but received ''"):
            client.files.with_raw_response.list_directory(
                "",
            )

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_load_editor_file(self, client: FluidizeSDK) -> None:
        file = client.files.load_editor_file(
            "file_path",
        )
        assert_matches_type(FileLoadEditorFileResponse, file, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_raw_response_load_editor_file(self, client: FluidizeSDK) -> None:
        response = client.files.with_raw_response.load_editor_file(
            "file_path",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        file = response.parse()
        assert_matches_type(FileLoadEditorFileResponse, file, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_streaming_response_load_editor_file(self, client: FluidizeSDK) -> None:
        with client.files.with_streaming_response.load_editor_file(
            "file_path",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            file = response.parse()
            assert_matches_type(FileLoadEditorFileResponse, file, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_path_params_load_editor_file(self, client: FluidizeSDK) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `file_path` but received ''"):
            client.files.with_raw_response.load_editor_file(
                "",
            )

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_save_editor_file(self, client: FluidizeSDK) -> None:
        file = client.files.save_editor_file(
            content="content",
            path="path",
        )
        assert_matches_type(SaveFileResponse, file, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_raw_response_save_editor_file(self, client: FluidizeSDK) -> None:
        response = client.files.with_raw_response.save_editor_file(
            content="content",
            path="path",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        file = response.parse()
        assert_matches_type(SaveFileResponse, file, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_streaming_response_save_editor_file(self, client: FluidizeSDK) -> None:
        with client.files.with_streaming_response.save_editor_file(
            content="content",
            path="path",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            file = response.parse()
            assert_matches_type(SaveFileResponse, file, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_save_file_content(self, client: FluidizeSDK) -> None:
        file = client.files.save_file_content(
            file_path="file_path",
            content="content",
            path="path",
        )
        assert_matches_type(SaveFileResponse, file, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_raw_response_save_file_content(self, client: FluidizeSDK) -> None:
        response = client.files.with_raw_response.save_file_content(
            file_path="file_path",
            content="content",
            path="path",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        file = response.parse()
        assert_matches_type(SaveFileResponse, file, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_streaming_response_save_file_content(self, client: FluidizeSDK) -> None:
        with client.files.with_streaming_response.save_file_content(
            file_path="file_path",
            content="content",
            path="path",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            file = response.parse()
            assert_matches_type(SaveFileResponse, file, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_path_params_save_file_content(self, client: FluidizeSDK) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `file_path` but received ''"):
            client.files.with_raw_response.save_file_content(
                file_path="",
                content="content",
                path="path",
            )

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_stream_file(self, client: FluidizeSDK) -> None:
        file = client.files.stream_file(
            "file_path",
        )
        assert_matches_type(object, file, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_raw_response_stream_file(self, client: FluidizeSDK) -> None:
        response = client.files.with_raw_response.stream_file(
            "file_path",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        file = response.parse()
        assert_matches_type(object, file, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_streaming_response_stream_file(self, client: FluidizeSDK) -> None:
        with client.files.with_streaming_response.stream_file(
            "file_path",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            file = response.parse()
            assert_matches_type(object, file, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_path_params_stream_file(self, client: FluidizeSDK) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `file_path` but received ''"):
            client.files.with_raw_response.stream_file(
                "",
            )


class TestAsyncFiles:
    parametrize = pytest.mark.parametrize(
        "async_client", [False, True, {"http_client": "aiohttp"}], indirect=True, ids=["loose", "strict", "aiohttp"]
    )

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_fetch_download_signed_url(self, async_client: AsyncFluidizeSDK) -> None:
        file = await async_client.files.fetch_download_signed_url(
            "file_path",
        )
        assert_matches_type(SignedURL, file, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_raw_response_fetch_download_signed_url(self, async_client: AsyncFluidizeSDK) -> None:
        response = await async_client.files.with_raw_response.fetch_download_signed_url(
            "file_path",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        file = await response.parse()
        assert_matches_type(SignedURL, file, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_streaming_response_fetch_download_signed_url(self, async_client: AsyncFluidizeSDK) -> None:
        async with async_client.files.with_streaming_response.fetch_download_signed_url(
            "file_path",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            file = await response.parse()
            assert_matches_type(SignedURL, file, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_path_params_fetch_download_signed_url(self, async_client: AsyncFluidizeSDK) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `file_path` but received ''"):
            await async_client.files.with_raw_response.fetch_download_signed_url(
                "",
            )

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_fetch_upload_signed_url(self, async_client: AsyncFluidizeSDK) -> None:
        file = await async_client.files.fetch_upload_signed_url(
            "file_path",
        )
        assert_matches_type(SignedURL, file, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_raw_response_fetch_upload_signed_url(self, async_client: AsyncFluidizeSDK) -> None:
        response = await async_client.files.with_raw_response.fetch_upload_signed_url(
            "file_path",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        file = await response.parse()
        assert_matches_type(SignedURL, file, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_streaming_response_fetch_upload_signed_url(self, async_client: AsyncFluidizeSDK) -> None:
        async with async_client.files.with_streaming_response.fetch_upload_signed_url(
            "file_path",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            file = await response.parse()
            assert_matches_type(SignedURL, file, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_path_params_fetch_upload_signed_url(self, async_client: AsyncFluidizeSDK) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `file_path` but received ''"):
            await async_client.files.with_raw_response.fetch_upload_signed_url(
                "",
            )

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_get_project_node_path(self, async_client: AsyncFluidizeSDK) -> None:
        file = await async_client.files.get_project_node_path(
            id="id",
            node_id="node_id",
        )
        assert_matches_type(str, file, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_get_project_node_path_with_all_params(self, async_client: AsyncFluidizeSDK) -> None:
        file = await async_client.files.get_project_node_path(
            id="id",
            node_id="node_id",
            description="description",
            label="label",
            location="location",
            metadata_version="metadata_version",
            status="status",
        )
        assert_matches_type(str, file, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_raw_response_get_project_node_path(self, async_client: AsyncFluidizeSDK) -> None:
        response = await async_client.files.with_raw_response.get_project_node_path(
            id="id",
            node_id="node_id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        file = await response.parse()
        assert_matches_type(str, file, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_streaming_response_get_project_node_path(self, async_client: AsyncFluidizeSDK) -> None:
        async with async_client.files.with_streaming_response.get_project_node_path(
            id="id",
            node_id="node_id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            file = await response.parse()
            assert_matches_type(str, file, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_get_simulation_path(self, async_client: AsyncFluidizeSDK) -> None:
        file = await async_client.files.get_simulation_path(
            node_id="node_id",
            sim_global=True,
        )
        assert_matches_type(str, file, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_raw_response_get_simulation_path(self, async_client: AsyncFluidizeSDK) -> None:
        response = await async_client.files.with_raw_response.get_simulation_path(
            node_id="node_id",
            sim_global=True,
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        file = await response.parse()
        assert_matches_type(str, file, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_streaming_response_get_simulation_path(self, async_client: AsyncFluidizeSDK) -> None:
        async with async_client.files.with_streaming_response.get_simulation_path(
            node_id="node_id",
            sim_global=True,
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            file = await response.parse()
            assert_matches_type(str, file, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_list_directory(self, async_client: AsyncFluidizeSDK) -> None:
        file = await async_client.files.list_directory(
            "file_path",
        )
        assert_matches_type(FileListDirectoryResponse, file, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_raw_response_list_directory(self, async_client: AsyncFluidizeSDK) -> None:
        response = await async_client.files.with_raw_response.list_directory(
            "file_path",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        file = await response.parse()
        assert_matches_type(FileListDirectoryResponse, file, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_streaming_response_list_directory(self, async_client: AsyncFluidizeSDK) -> None:
        async with async_client.files.with_streaming_response.list_directory(
            "file_path",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            file = await response.parse()
            assert_matches_type(FileListDirectoryResponse, file, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_path_params_list_directory(self, async_client: AsyncFluidizeSDK) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `file_path` but received ''"):
            await async_client.files.with_raw_response.list_directory(
                "",
            )

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_load_editor_file(self, async_client: AsyncFluidizeSDK) -> None:
        file = await async_client.files.load_editor_file(
            "file_path",
        )
        assert_matches_type(FileLoadEditorFileResponse, file, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_raw_response_load_editor_file(self, async_client: AsyncFluidizeSDK) -> None:
        response = await async_client.files.with_raw_response.load_editor_file(
            "file_path",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        file = await response.parse()
        assert_matches_type(FileLoadEditorFileResponse, file, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_streaming_response_load_editor_file(self, async_client: AsyncFluidizeSDK) -> None:
        async with async_client.files.with_streaming_response.load_editor_file(
            "file_path",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            file = await response.parse()
            assert_matches_type(FileLoadEditorFileResponse, file, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_path_params_load_editor_file(self, async_client: AsyncFluidizeSDK) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `file_path` but received ''"):
            await async_client.files.with_raw_response.load_editor_file(
                "",
            )

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_save_editor_file(self, async_client: AsyncFluidizeSDK) -> None:
        file = await async_client.files.save_editor_file(
            content="content",
            path="path",
        )
        assert_matches_type(SaveFileResponse, file, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_raw_response_save_editor_file(self, async_client: AsyncFluidizeSDK) -> None:
        response = await async_client.files.with_raw_response.save_editor_file(
            content="content",
            path="path",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        file = await response.parse()
        assert_matches_type(SaveFileResponse, file, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_streaming_response_save_editor_file(self, async_client: AsyncFluidizeSDK) -> None:
        async with async_client.files.with_streaming_response.save_editor_file(
            content="content",
            path="path",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            file = await response.parse()
            assert_matches_type(SaveFileResponse, file, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_save_file_content(self, async_client: AsyncFluidizeSDK) -> None:
        file = await async_client.files.save_file_content(
            file_path="file_path",
            content="content",
            path="path",
        )
        assert_matches_type(SaveFileResponse, file, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_raw_response_save_file_content(self, async_client: AsyncFluidizeSDK) -> None:
        response = await async_client.files.with_raw_response.save_file_content(
            file_path="file_path",
            content="content",
            path="path",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        file = await response.parse()
        assert_matches_type(SaveFileResponse, file, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_streaming_response_save_file_content(self, async_client: AsyncFluidizeSDK) -> None:
        async with async_client.files.with_streaming_response.save_file_content(
            file_path="file_path",
            content="content",
            path="path",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            file = await response.parse()
            assert_matches_type(SaveFileResponse, file, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_path_params_save_file_content(self, async_client: AsyncFluidizeSDK) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `file_path` but received ''"):
            await async_client.files.with_raw_response.save_file_content(
                file_path="",
                content="content",
                path="path",
            )

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_stream_file(self, async_client: AsyncFluidizeSDK) -> None:
        file = await async_client.files.stream_file(
            "file_path",
        )
        assert_matches_type(object, file, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_raw_response_stream_file(self, async_client: AsyncFluidizeSDK) -> None:
        response = await async_client.files.with_raw_response.stream_file(
            "file_path",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        file = await response.parse()
        assert_matches_type(object, file, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_streaming_response_stream_file(self, async_client: AsyncFluidizeSDK) -> None:
        async with async_client.files.with_streaming_response.stream_file(
            "file_path",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            file = await response.parse()
            assert_matches_type(object, file, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_path_params_stream_file(self, async_client: AsyncFluidizeSDK) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `file_path` but received ''"):
            await async_client.files.with_raw_response.stream_file(
                "",
            )
